@@ -14,8 +14,8 @@
 
    You should have received a copy of the GNU Library General Public
    License along with the Gnome Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301  USA.
 
    Author: Bastien Nocera <hadess@hadess.net>
  */
@@ -28,7 +28,6 @@
 #ifndef TOTEM_PL_PARSER_MINI
 #include "xmlparser.h"
 #include <gtk/gtk.h>
-#include <libgnomevfs/gnome-vfs.h>
 #include "totem-pl-parser.h"
 #include "totemplparser-marshal.h"
 #endif /* !TOTEM_PL_PARSER_MINI */
@@ -58,8 +57,7 @@ totem_pl_parser_is_quicktime (const char *data, gsize len)
 	if (g_str_has_prefix (data, "SMILtext") != FALSE)
 		return QUICKTIME_META_MIME_TYPE;
 
-	if (memmem (data, len,
-		    QT_NEEDLE, strlen (QT_NEEDLE)) != NULL)
+	if (g_strstr_len (data, len, QT_NEEDLE) != NULL)
 		return QUICKTIME_META_MIME_TYPE;
 
 	return NULL;
@@ -69,17 +67,17 @@ totem_pl_parser_is_quicktime (const char *data, gsize len)
 
 static TotemPlParserResult
 totem_pl_parser_add_quicktime_rtsptext (TotemPlParser *parser,
-					const char *url,
-					const char *base,
+					GFile *file,
+					GFile *base_file,
 					gpointer data)
 {
 	char *contents = NULL;
 	gboolean dos_mode = FALSE;
 	char *volume, *autoplay, *rtspurl;
-	int size;
+	gsize size;
 	char **lines;
 
-	if (gnome_vfs_read_entire_file (url, &size, &contents) != GNOME_VFS_OK)
+	if (g_file_load_contents (file, NULL, &contents, &size, NULL, NULL) == FALSE)
 		return TOTEM_PL_PARSER_RESULT_ERROR;
 
 	if (strstr(contents,"\x0d") != NULL)
@@ -113,36 +111,37 @@ totem_pl_parser_add_quicktime_rtsptext (TotemPlParser *parser,
 }
 
 static TotemPlParserResult
-totem_pl_parser_add_quicktime_metalink (TotemPlParser *parser, const char *url,
-					const char *base, gpointer data)
+totem_pl_parser_add_quicktime_metalink (TotemPlParser *parser,
+					GFile *file,
+					GFile *base_file, gpointer data)
 {
 	xml_node_t *doc, *node;
-	int size;
+	gsize size;
 	char *contents;
 	const char *item_url, *autoplay;
 	gboolean found;
 
 	if (g_str_has_prefix (data, "RTSPtext") != FALSE
 			|| g_str_has_prefix (data, "rtsptext") != FALSE) {
-		return totem_pl_parser_add_quicktime_rtsptext (parser, url, base, data);
+		return totem_pl_parser_add_quicktime_rtsptext (parser, file, base_file, data);
 	}
 	if (g_str_has_prefix (data, "SMILtext") != FALSE) {
 		char *contents;
-		int size;
+		gsize size;
 		TotemPlParserResult retval;
 
-		if (gnome_vfs_read_entire_file (url, &size, &contents) != GNOME_VFS_OK)
+		if (g_file_load_contents (file, NULL, &contents, &size, NULL, NULL) == FALSE)
 			return TOTEM_PL_PARSER_RESULT_ERROR;
 
 		retval = totem_pl_parser_add_smil_with_data (parser,
-							     url, base,
+							     file, base_file,
 							     contents + strlen ("SMILtext"),
 							     size - strlen ("SMILtext"));
 		g_free (contents);
 		return retval;
 	}
 
-	if (gnome_vfs_read_entire_file (url, &size, &contents) != GNOME_VFS_OK)
+	if (g_file_load_contents (file, NULL, &contents, &size, NULL, NULL) == FALSE)
 		return TOTEM_PL_PARSER_RESULT_ERROR;
 
 	xml_parser_init (contents, size, XML_PARSER_CASE_INSENSITIVE);
@@ -198,15 +197,21 @@ totem_pl_parser_add_quicktime_metalink (TotemPlParser *parser, const char *url,
 }
 
 TotemPlParserResult
-totem_pl_parser_add_quicktime (TotemPlParser *parser, const char *url,
-			       const char *base, gpointer data)
+totem_pl_parser_add_quicktime (TotemPlParser *parser,
+			       GFile *file,
+			       GFile *base_file,
+			       gpointer data)
 {
 	if (data == NULL || totem_pl_parser_is_quicktime (data, strlen (data)) == NULL) {
+		char *url;
+
+		url = g_file_get_uri (file);
 		totem_pl_parser_add_one_url (parser, url, NULL);
+		g_free (url);
 		return TOTEM_PL_PARSER_RESULT_SUCCESS;
 	}
 
-	return totem_pl_parser_add_quicktime_metalink (parser, url, base, data);
+	return totem_pl_parser_add_quicktime_metalink (parser, file, base_file, data);
 }
 
 #endif /* !TOTEM_PL_PARSER_MINI */
